netapp_ontap.models.lun_location API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_location`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunLocationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunLocation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `logical_unit GET POST PATCH`

    The base name component of the LUN. Valid in POST and PATCH.
    If properties `name` and `location.logical_unit` are specified in the same request, they must refer to the base name.
    A PATCH that modifies the base name of the LUN is considered a rename operation.

    Example: lun1

  `qtree GET POST PATCH`

    The qtree field of the lun_location.

  `volume GET POST PATCH`

    The volume field of the lun_location.